@@ -1,7 +1,7 @@
 package Getopt::Long::Subcommand;
 
 our $DATE = '2017-01-06'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -18,6 +18,7 @@ our @EXPORT = qw(
 my @known_cmdspec_keys = qw(
     options
     subcommands
+    default_subcommand
     summary description
     completion
 );
@@ -128,12 +129,25 @@ sub _GetOptions {
                 [sort keys %{$cmdspec->{subcommands}}];
         }
 
-        unless (@ARGV) {
-            # no subcommand name
+        $res->{subcommand} //= [];
+
+        my $push;
+        my $sc_name;
+
+        if (defined $res->{subcommand}[ $stash->{level} ]) {
+            # subcommand has been set, e.g. by option handler
+            $sc_name = $res->{subcommand}[ $stash->{level} ];
+        } elsif (@ARGV) {
+            $sc_name = shift @ARGV;
+            $push++; # we need to push to $res->{subcommand} later
+        } elsif (defined $cmdspec->{default_subcommand}) {
+            $sc_name = $cmdspec->{default_subcommand};
+            $push++;
+        } else {
+            # no subcommand
             $res->{success} = 1;
             return $res;
         }
-        my $sc_name = shift @ARGV;
 
         # for doing completion of subcommand names
         if ($is_completion) {
@@ -148,8 +162,7 @@ sub _GetOptions {
             $res->{success} = 0;
             return $res;
         };
-        $res->{subcommand} //= [];
-        push @{ $res->{subcommand} }, $sc_name;
+        push @{ $res->{subcommand} }, $sc_name if $push;
         local $stash->{path} = ($stash->{path} ? "/" : "") . $sc_name;
         local $stash->{level} = $stash->{level}+1;
         _GetOptions($sc_spec, $is_completion, $res, $stash);
@@ -261,7 +274,7 @@ Getopt::Long::Subcommand - Process command-line options, with subcommands and co
 
 =head1 VERSION
 
-This document describes version 0.08 of Getopt::Long::Subcommand (from Perl distribution Getopt-Long-Subcommand), released on 2017-01-06.
+This document describes version 0.09 of Getopt::Long::Subcommand (from Perl distribution Getopt-Long-Subcommand), released on 2017-01-06.
 
 =head1 SYNOPSIS
 
@@ -404,6 +417,14 @@ A hash of subcommand name and its specification. The specification looks like
 C<GetOptions> argument, with keys like C<summary>, C<options>, C<subcommands>
 (for nested subcommands).
 
+=item * default_subcommand => str
+
+Default subcommand to use if no subcommand name is set. Subcommand can be set
+using the first argument, or your option handler can also set the subcommand
+using:
+
+ $_[2]{subcommand_name} = 'something';
+
 =back
 
 Differences with C<Getopt::Long>'s C<GetOptions>:
